@echo OFF
     set CmdName=CBLCLTE1
rem  * *******************************************************************
rem  *                Job Script - a Windows Command File                *
rem  *                 Provided by SimoTime Technologies                 *
rem  *            (C) Copyright 1987-2019 All Rights Reserved            *
rem  *              Web Site URL:   http://www.simotime.com              *
rem  *                    e-mail:   helpdesk@simotime.com                *
rem  * *******************************************************************
rem  *
rem  * Text   - Create, Sort and Process a Sequential file using
rem  *          a COBOL program.
rem  * Author - SimoTime Technologies
rem  * Date   - January 24, 1996
rem  *
rem  * The 1st step (QSAMDELT) will delete any previously created file.
rem  *
rem  * The 2nd step (MAKEFILE) will create a new file. The first
rem  * position in each record will contain a printable character.
rem  *
rem  * The 3rd step will show a program that works properly in an
rem  * EBCDIC environment but fails in an ASCII environment.
rem  *
rem  * The 4th step will SORT the file. This step will produce different
rem  * results when executing on an EBCDIC or ASCII environment.
rem  *
rem  * The 5th step shows the sequencing for the two environments and
rem  * will worked properly in an EBCDIC environment but fail in an
rem  * ASCII environment.
rem  *
rem  * This set of programs will run on a mainframe under MVS or on a
rem  * Personal Computer with Windows and Micro Focus Mainframe Express.
rem  *
rem  * *******************************************************************
rem  * Step 1 Delete any previously created file...
rem  *
     call ..\Env1BASE %CmdName%
     set JobStatus=0000
     if "%SYSLOG%" == "" set syslog=c:\SimoLIBR\LOGS\SimoTime.LOG
rem  *
     call SimoNOTE "*******************************************************%CmdName%"
     call SimoNOTE "Starting CmdName %CmdName%, V04.08.13, User is %USERNAME%"
     set SYSOUT=%BaseLib1%\LOGS\SYSOUT_%CmdName%.TXT
:DeleteQSAM
     call SimoNOTE "Identify JobStep DeleteQSAM"
     set COLLATE1=%BaseLib1%\DATA\Asc1\COLLATE1.DAT
     set COLLATE2=%BaseLib1%\DATA\Asc1\COLLATE2.DAT
     set COLLATE3=%BaseLib1%\DATA\Asc1\COLLATE3.DAT
     set COLLATE4=%BaseLib1%\DATA\Asc1\COLLATE4.DAT
     if exist %COLLATE1% del %COLLATE1%
     if exist %COLLATE2% del %COLLATE2%
     if exist %COLLATE3% del %COLLATE3%
     if exist %COLLATE4% del %COLLATE4%
rem  *
rem  * *******************************************************************
rem  * Step 2 Create and populate a new QSAM file...
rem  *
:MakeFile
     call SimoNOTE "Identify JobStep MakeFile"
     set COLLATE1=%BaseLib1%\DATA\Asc1\COLLATE1.DAT
     set COLLATE2=%BaseLib1%\DATA\Asc1\COLLATE2.DAT
     run CBLCLTC2
     if ERRORLEVEL = 1 set JobStatus=0020
     if not "%JobStatus%" == "0000" goto :EojNok
rem  *
rem  * *******************************************************************
rem  * Step 3 Test for printable character, create a new output file.
rem  *        the program used in this step will perform correctly
rem  *        in an EBCDIC environment but fail in an ASCII environment
rem  *
:Test0001
     call SimoNOTE "Identify JobStep Test0001"
     set COLLATE1=%BaseLib1%\DATA\Asc1\COLLATE1.DAT
     set COLLATE2=%BaseLib1%\DATA\Asc1\COLLATE2.DAT
     run CBLCLTC1
     if ERRORLEVEL = 1 set JobStatus=0030
     if not "%JobStatus%" == "0000" goto :EojNok
rem  * *******************************************************************
rem  * Step 4 Sort by character set using a cobol program. This step will
rem  *        produce different sequencing results when running in an
rem  *        EBCDIC or ASCII environment.
rem  *
:SortFile
     call SimoNOTE "Identify JobStep SortFile"
     set SORTGET1=%BaseLib1%\DATA\Asc1\COLLATE1.DAT
     set SORTPUT1=%BaseLib1%\DATA\Asc1\COLLATE3.DAT
rem  set MF_ALIAS=MFJSORT SORT
     run CBLS80C1
     if ERRORLEVEL = 1 set JobStatus=0040
     if not "%JobStatus%" == "0000" goto :EojNok
rem  *
rem  * *******************************************************************
rem  * Step 5 Test for printable character, create a new output file.
rem  *        the program used in this step will perform correctly
rem  *        in an EBCDIC environment but fail in an ASCII environment.
rem  *        This step uses the sorted file and shows the sequencing
rem  *        that will be different when running in an EBCDIC or ASCII
rem  *        environment.
rem  *
:Test0002
     call SimoNOTE "Identify JobStep Test0002"
     set COLLATE1=%BaseLib1%\DATA\Asc1\COLLATE3.DAT
     set COLLATE2=%BaseLib1%\DATA\Asc1\COLLATE4.DAT
     run CBLCLTC1
     if ERRORLEVEL = 1 set JobStatus=0050
     if not "%JobStatus%" == "0000" goto :EojNok
     goto :EojAok
rem  *
:EojNok
     call SimoNOTE "ABENDING CmdName %CmdName%, JobStatus %JobStatus%"
     pause
     goto :End
:EojAok
     call SimoNOTE "Finished CmdName %CmdName%, JobStatus %JobStatus%"
:End
     call SimoNOTE "Conclude SysLog is %SYSLOG%"
     if not "%1" == "nopause" pause
